==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/coredata/NSAsynchronousFetchRequest.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coredata;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 8.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("CoreData") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/NSAsynchronousFetchRequest/*</name>*/ 
    extends /*<extends>*/NSPersistentStoreRequest/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class NSAsynchronousFetchRequestPtr extends Ptr<NSAsynchronousFetchRequest, NSAsynchronousFetchRequestPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(NSAsynchronousFetchRequest.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public NSAsynchronousFetchRequest() {}
    protected NSAsynchronousFetchRequest(SkipInit skipInit) { super(skipInit); }
    public NSAsynchronousFetchRequest(NSFetchRequest request, @Block VoidBlock1<NSAsynchronousFetchResult> blk) { super((SkipInit) null); initObject(init(request, blk)); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "fetchRequest")
    public native NSFetchRequest getFetchRequest();
    @Property(selector = "completionBlock")
    public native @Block VoidBlock1<NSAsynchronousFetchResult> getCompletionBlock();
    @Property(selector = "estimatedResultCount")
    public native @MachineSizedSInt long getEstimatedResultCount();
    @Property(selector = "setEstimatedResultCount:")
    public native void setEstimatedResultCount(@MachineSizedSInt long v);
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "initWithFetchRequest:completionBlock:")
    protected native @Pointer long init(NSFetchRequest request, @Block VoidBlock1<NSAsynchronousFetchResult> blk);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/coredata/NSAsynchronousFetchRequest.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coredata;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corespotlight.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.uikit.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("CoreData") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/NSAsynchronousFetchRequest<ResultType extends NSObject & NSFetchRequestResult>/*</name>*/ 
    extends /*<extends>*/NSPersistentStoreRequest/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class NSAsynchronousFetchRequestPtr<ResultType extends NSObject & NSFetchRequestResult> extends Ptr<NSAsynchronousFetchRequest<ResultType>, NSAsynchronousFetchRequestPtr<ResultType>> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(NSAsynchronousFetchRequest.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public NSAsynchronousFetchRequest() {}
    protected NSAsynchronousFetchRequest(Handle h, long handle) { super(h, handle); }
    protected NSAsynchronousFetchRequest(SkipInit skipInit) { super(skipInit); }
    @Method(selector = "initWithFetchRequest:completionBlock:")
    public NSAsynchronousFetchRequest(NSFetchRequest<ResultType> request, @Block VoidBlock1<NSAsynchronousFetchResult> blk) { super((SkipInit) null); initObject(init(request, blk)); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "fetchRequest")
    public native NSFetchRequest<ResultType> getFetchRequest();
    @Property(selector = "completionBlock")
    public native @Block VoidBlock1<NSAsynchronousFetchResult> getCompletionBlock();
    @Property(selector = "estimatedResultCount")
    public native @MachineSizedSInt long getEstimatedResultCount();
    @Property(selector = "setEstimatedResultCount:")
    public native void setEstimatedResultCount(@MachineSizedSInt long v);
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "initWithFetchRequest:completionBlock:")
    protected native @Pointer long init(NSFetchRequest<ResultType> request, @Block VoidBlock1<NSAsynchronousFetchResult> blk);
    /*</methods>*/
}
